==> vxl_1.13.0.orig.tar.gz: vxl-1.13.0/core/vnl/tests/test_include.cxx <==
#include <vnl/vnl_fwd.h>

#include <vnl/vnl_T_n.h>
#include <vnl/vnl_alloc.h>
#include <vnl/vnl_analytic_integrant.h>
#include <vnl/vnl_bessel.h>
#include <vnl/vnl_bignum.h>
#include <vnl/vnl_bignum_traits.h>
#include <vnl/vnl_block.h>
#include <vnl/vnl_c_vector.h>
#include <vnl/vnl_complex.h>
#include <vnl/vnl_complexify.h>
#include <vnl/vnl_complex_traits.h>
#include <vnl/vnl_copy.h>
#include <vnl/vnl_cross.h>
#include <vnl/vnl_crs_index.h>
#include <vnl/vnl_cost_function.h>
#include <vnl/vnl_cross_product_matrix.h>
#include <vnl/vnl_definite_integral.h>
#include <vnl/vnl_det.h>
#include <vnl/vnl_diag_matrix.h>
#include <vnl/vnl_double_1x1.h>
#include <vnl/vnl_double_1x2.h>
#include <vnl/vnl_double_1x3.h>
#include <vnl/vnl_double_2.h>
#include <vnl/vnl_double_2x1.h>
#include <vnl/vnl_double_2x2.h>
#include <vnl/vnl_double_2x3.h>
#include <vnl/vnl_double_3.h>
#include <vnl/vnl_double_3x1.h>
#include <vnl/vnl_double_3x2.h>
#include <vnl/vnl_double_3x3.h>
#include <vnl/vnl_double_3x4.h>
#include <vnl/vnl_double_4.h>
#include <vnl/vnl_double_4x3.h>
#include <vnl/vnl_double_4x4.h>
#include <vnl/vnl_erf.h>
#include <vnl/vnl_error.h>
#include <vnl/vnl_fastops.h>
#include <vnl/vnl_file_matrix.h>
#include <vnl/vnl_file_vector.h>
#include <vnl/vnl_finite.h>
#include <vnl/vnl_float_1x1.h>
#include <vnl/vnl_float_1x2.h>
#include <vnl/vnl_float_1x3.h>
#include <vnl/vnl_float_2.h>
#include <vnl/vnl_float_2x1.h>
#include <vnl/vnl_float_2x2.h>
#include <vnl/vnl_float_3.h>
#include <vnl/vnl_float_3x1.h>
#include <vnl/vnl_float_3x3.h>
#include <vnl/vnl_float_3x4.h>
#include <vnl/vnl_float_4.h>
#include <vnl/vnl_float_4x3.h>
#include <vnl/vnl_float_4x4.h>
#include <vnl/vnl_fortran_copy.h>
#include <vnl/vnl_gamma.h>
#include <vnl/vnl_hungarian_algorithm.h>
#include <vnl/vnl_identity.h>
#include <vnl/vnl_identity_3x3.h>
#include <vnl/vnl_imag.h>
#include <vnl/vnl_int_1x1.h>
#include <vnl/vnl_int_2.h>
#include <vnl/vnl_int_2x2.h>
#include <vnl/vnl_int_3.h>
#include <vnl/vnl_int_4.h>
#include <vnl/vnl_int_matrix.h>
#include <vnl/vnl_integrant_fnct.h>
#include <vnl/vnl_inverse.h>
#include <vnl/vnl_least_squares_cost_function.h>
#include <vnl/vnl_least_squares_function.h>
#include <vnl/vnl_linear_operators_3.h>
#include <vnl/vnl_linear_system.h>
#include <vnl/vnl_math.h>
#include <vnl/vnl_matlab_filewrite.h>
#include <vnl/vnl_matlab_header.h>
#include <vnl/vnl_matlab_print.h>
#include <vnl/vnl_matlab_print2.h>
#include <vnl/vnl_matlab_print_format.h>
#include <vnl/vnl_matlab_print_scalar.h>
#include <vnl/vnl_matlab_read.h>
#include <vnl/vnl_matlab_write.h>
#include <vnl/vnl_matops.h>
#include <vnl/vnl_matrix.h>
#include <vnl/vnl_matrix_exp.h>
#include <vnl/vnl_matrix_fixed.h>
#include <vnl/vnl_matrix_ref.h>
#include <vnl/vnl_matrix_fixed_ref.h>
#include <vnl/vnl_nonlinear_minimizer.h>
#include <vnl/vnl_numeric_traits.h>
#include <vnl/vnl_operators.h>
#include <vnl/vnl_power.h>
#include <vnl/vnl_quaternion.h>
#include <vnl/vnl_rank.h>
#include <vnl/vnl_random.h>
#include <vnl/vnl_rational.h>
#include <vnl/vnl_rational_traits.h>
#include <vnl/vnl_real.h>
#include <vnl/vnl_real_npolynomial.h>
#include <vnl/vnl_real_polynomial.h>
#include <vnl/vnl_rotation_matrix.h>
#include <vnl/vnl_sample.h>
#include <vnl/vnl_scalar_join_iterator.h>
#include <vnl/vnl_sparse_lst_sqr_function.h>
#include <vnl/vnl_sparse_matrix.h>
#include <vnl/vnl_sparse_matrix_linear_system.h>
#include <vnl/vnl_sse.h>
#include <vnl/vnl_sym_matrix.h>
#include <vnl/vnl_tag.h>
#include <vnl/vnl_trace.h>
#include <vnl/vnl_transpose.h>
#include <vnl/vnl_unary_function.h>
#include <vnl/vnl_vector.h>
#include <vnl/vnl_vector_fixed.h>
#include <vnl/vnl_vector_ref.h>
#include <vnl/vnl_vector_fixed_ref.h>

#include <vnl/xio/vnl_xio_matrix_fixed.h>
#include <vnl/xio/vnl_xio_quaternion.h>
#include <vnl/xio/vnl_xio_vector.h>
#include <vnl/xio/vnl_xio_vector_fixed.h>

// Put vnl_config.h at the end, to verify that none of the above implicitly depend on it
#include <vnl/vnl_config.h>

int main() { return 0; }

==> vxl_1.14.0.orig.tar.gz: vxl-1.14.0/core/vnl/tests/test_include.cxx <==
#include <vnl/vnl_fwd.h>

#include <vnl/vnl_T_n.h>
#include <vnl/vnl_alloc.h>
#include <vnl/vnl_analytic_integrant.h>
#include <vnl/vnl_bessel.h>
#include <vnl/vnl_beta.h>
#include <vnl/vnl_bignum.h>
#include <vnl/vnl_bignum_traits.h>
#include <vnl/vnl_block.h>
#include <vnl/vnl_c_vector.h>
#include <vnl/vnl_complex.h>
#include <vnl/vnl_complexify.h>
#include <vnl/vnl_complex_traits.h>
#include <vnl/vnl_copy.h>
#include <vnl/vnl_cross.h>
#include <vnl/vnl_crs_index.h>
#include <vnl/vnl_cost_function.h>
#include <vnl/vnl_cross_product_matrix.h>
#include <vnl/vnl_definite_integral.h>
#include <vnl/vnl_det.h>
#include <vnl/vnl_diag_matrix.h>
#include <vnl/vnl_diag_matrix_fixed.h>
#include <vnl/vnl_double_1x1.h>
#include <vnl/vnl_double_1x2.h>
#include <vnl/vnl_double_1x3.h>
#include <vnl/vnl_double_2.h>
#include <vnl/vnl_double_2x1.h>
#include <vnl/vnl_double_2x2.h>
#include <vnl/vnl_double_2x3.h>
#include <vnl/vnl_double_3.h>
#include <vnl/vnl_double_3x1.h>
#include <vnl/vnl_double_3x2.h>
#include <vnl/vnl_double_3x3.h>
#include <vnl/vnl_double_3x4.h>
#include <vnl/vnl_double_4.h>
#include <vnl/vnl_double_4x3.h>
#include <vnl/vnl_double_4x4.h>
#include <vnl/vnl_erf.h>
#include <vnl/vnl_error.h>
#include <vnl/vnl_fastops.h>
#include <vnl/vnl_file_matrix.h>
#include <vnl/vnl_file_vector.h>
#include <vnl/vnl_finite.h>
#include <vnl/vnl_float_1x1.h>
#include <vnl/vnl_float_1x2.h>
#include <vnl/vnl_float_1x3.h>
#include <vnl/vnl_float_2.h>
#include <vnl/vnl_float_2x1.h>
#include <vnl/vnl_float_2x2.h>
#include <vnl/vnl_float_3.h>
#include <vnl/vnl_float_3x1.h>
#include <vnl/vnl_float_3x3.h>
#include <vnl/vnl_float_3x4.h>
#include <vnl/vnl_float_4.h>
#include <vnl/vnl_float_4x3.h>
#include <vnl/vnl_float_4x4.h>
#include <vnl/vnl_fortran_copy.h>
#include <vnl/vnl_fortran_copy_fixed.h>
#include <vnl/vnl_gamma.h>
#include <vnl/vnl_hungarian_algorithm.h>
#include <vnl/vnl_identity.h>
#include <vnl/vnl_identity_3x3.h>
#include <vnl/vnl_imag.h>
#include <vnl/vnl_int_1x1.h>
#include <vnl/vnl_int_2.h>
#include <vnl/vnl_int_2x2.h>
#include <vnl/vnl_int_3.h>
#include <vnl/vnl_int_4.h>
#include <vnl/vnl_int_matrix.h>
#include <vnl/vnl_integrant_fnct.h>
#include <vnl/vnl_inverse.h>
#include <vnl/vnl_least_squares_cost_function.h>
#include <vnl/vnl_least_squares_function.h>
#include <vnl/vnl_linear_operators_3.h>
#include <vnl/vnl_linear_system.h>
#include <vnl/vnl_math.h>
#include <vnl/vnl_matlab_filewrite.h>
#include <vnl/vnl_matlab_header.h>
#include <vnl/vnl_matlab_print.h>
#include <vnl/vnl_matlab_print2.h>
#include <vnl/vnl_matlab_print_format.h>
#include <vnl/vnl_matlab_print_scalar.h>
#include <vnl/vnl_matlab_read.h>
#include <vnl/vnl_matlab_write.h>
#include <vnl/vnl_matops.h>
#include <vnl/vnl_matrix.h>
#include <vnl/vnl_matrix_exp.h>
#include <vnl/vnl_matrix_fixed.h>
#include <vnl/vnl_matrix_ref.h>
#include <vnl/vnl_matrix_fixed_ref.h>
#include <vnl/vnl_na.h>
#include <vnl/vnl_nonlinear_minimizer.h>
#include <vnl/vnl_numeric_traits.h>
#include <vnl/vnl_operators.h>
#include <vnl/vnl_power.h>
#include <vnl/vnl_quaternion.h>
#include <vnl/vnl_rank.h>
#include <vnl/vnl_random.h>
#include <vnl/vnl_rational.h>
#include <vnl/vnl_rational_traits.h>
#include <vnl/vnl_real.h>
#include <vnl/vnl_real_npolynomial.h>
#include <vnl/vnl_real_polynomial.h>
#include <vnl/vnl_rotation_matrix.h>
#include <vnl/vnl_sample.h>
#include <vnl/vnl_scalar_join_iterator.h>
#include <vnl/vnl_sparse_lst_sqr_function.h>
#include <vnl/vnl_sparse_matrix.h>
#include <vnl/vnl_sparse_matrix_linear_system.h>
#include <vnl/vnl_sse.h>
#include <vnl/vnl_sym_matrix.h>
#include <vnl/vnl_tag.h>
#include <vnl/vnl_trace.h>
#include <vnl/vnl_transpose.h>
#include <vnl/vnl_unary_function.h>
#include <vnl/vnl_vector.h>
#include <vnl/vnl_vector_fixed.h>
#include <vnl/vnl_vector_ref.h>
#include <vnl/vnl_vector_fixed_ref.h>

#include <vnl/xio/vnl_xio_matrix_fixed.h>
#include <vnl/xio/vnl_xio_quaternion.h>
#include <vnl/xio/vnl_xio_vector.h>
#include <vnl/xio/vnl_xio_vector_fixed.h>

// Put vnl_config.h at the end, to verify that none of the above implicitly depend on it
#include <vnl/vnl_config.h>

int main() { return 0; }
